summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMichele Calgaro <[email protected]>2024-02-25 14:22:54 +0900
committerMichele Calgaro <[email protected]>2024-02-25 14:22:54 +0900
commite6473e544e16ca46e5ca4f5ca8a38b2b7ffb61e3 (patch)
tree643ad049be53434b9d8afaa57d58651a65b0d9c4
parent31eb157b2f618dcc60bf36dcca18dcb812edce34 (diff)
downloadkaffeine-e6473e544e16ca46e5ca4f5ca8a38b2b7ffb61e3.tar.gz
kaffeine-e6473e544e16ca46e5ca4f5ca8a38b2b7ffb61e3.zip
Replace Qt with TQt
Signed-off-by: Michele Calgaro <[email protected]>
-rw-r--r--doc/man/kaffeine.110
-rw-r--r--kaffeine/src/player-parts/xine-part/kxinewidget.cpp8
-rw-r--r--kaffeine/src/player-parts/xine-part/kxinewidget.h4
3 files changed, 11 insertions, 11 deletions
diff --git a/doc/man/kaffeine.1 b/doc/man/kaffeine.1
index 0d66e29..907cb6d 100644
--- a/doc/man/kaffeine.1
+++ b/doc/man/kaffeine.1
@@ -4,7 +4,7 @@
kaffeine
- A media player for TDE that can use multiple backends for playback.
.SH SYNOPSIS
-kaffeine [Qt-options] [TDE-options] [options] [file]
+kaffeine [TQt-options] [TDE-options] [options] [file]
.SH DESCRIPTION
Kaffeine is a media player for TDE. While it supports multiple player
engines, its default engine is Xine, giving Kaffeine a wide variety of
@@ -52,8 +52,8 @@ Run installation wizard
.B --help
Show help about options
.TP
-.B --help-qt
-Show Qt specific options
+.B --help-tqt
+Show TQt specific options
.TP
.B --help-tde
Show TDE specific options
@@ -105,7 +105,7 @@ sets the client geometry of the main widget - see man X for the argument format
.B --nofork
Don't run in the background.
.SS
-.SS Qt options:
+.SS TQt options:
.TP
.B --display <displayname>
Use the X-server display 'displayname'
@@ -124,7 +124,7 @@ using the QApplication::ManyColor color
specification
.TP
.B --nograb
-tells Qt to never grab the mouse or the keyboard
+tells TQt to never grab the mouse or the keyboard
.TP
.B --dograb
running under a debugger can cause an implicit
diff --git a/kaffeine/src/player-parts/xine-part/kxinewidget.h b/kaffeine/src/player-parts/xine-part/kxinewidget.h
index 811df93..c9e1155 100644
--- a/kaffeine/src/player-parts/xine-part/kxinewidget.h
+++ b/kaffeine/src/player-parts/xine-part/kxinewidget.h
@@ -1,5 +1,5 @@
/*
- * kxinewidget.h - a kde / qt api for xine-lib
+ * kxinewidget.h - a tde / tqt api for xine-lib
*
* Copyright (C) 2003-2005 Jürgen Kofler <[email protected]>
* Copyright (C) 2005-2006 Christophe Thommeret <[email protected]>
@@ -22,7 +22,7 @@
#ifndef KXINEWIDGET_H
#define KXINEWIDGET_H
-/* define this if you want to use QT only - disables post plugin support (except visualization)! */
+/* define this if you want to use TQt only - disables post plugin support (except visualization)! */
//#define USE_TQT_ONLY 1
/* Usage:
diff --git a/kaffeine/src/player-parts/xine-part/kxinewidget.cpp b/kaffeine/src/player-parts/xine-part/kxinewidget.cpp
index 4cb52a2..c6535e6 100644
--- a/kaffeine/src/player-parts/xine-part/kxinewidget.cpp
+++ b/kaffeine/src/player-parts/xine-part/kxinewidget.cpp
@@ -1,5 +1,5 @@
/*
* kxinewidget.cpp - a kde / qt api for xine-lib
*
* Copyright (C) 2003-2005 Jürgen Kofler <[email protected]>
* Copyright (C) 2005-2006 Christophe Thommeret <[email protected]>
@@ -364,9 +364,9 @@ void KXineWidget::frameOutputCallback(void* p, int video_width, int video_height
/*
* XINE EVENT THREAD
* only the QT event thread should do GUI operations,
* we use TQApplication::postEvent() and a reimplementation of TQObject::timerEvent() to
* make sure all critical jobs are done within the QT main thread context
*
* for more information see http://doc.trolltech.com/3.1/threads.html
*/
@@ -4048,7 +4048,7 @@ uchar* KXineWidget::yv12ToRgb (uint8_t *src_y, uint8_t *src_u, uint8_t *src_v, i
uv_width = width / 2;
uv_height = height / 2;
- rgb = new uchar[(width * height * 4)]; //qt needs a 32bit align
+ rgb = new uchar[(width * height * 4)]; //tqt needs a 32bit align
if (!rgb)
{
// kdError(555) << "Not enough memory!" << endl;
@@ -1,5 +1,5 @@
/*
- * kxinewidget.cpp - a kde / qt api for xine-lib
+ * kxinewidget.cpp - a tde / tqt api for xine-lib
*
* Copyright (C) 2003-2005 Jürgen Kofler <[email protected]>
@@ -364,9 +364,9 @@ void KXineWidget::frameOutputCallback(void* p, int video_width, int video_height
/*
* XINE EVENT THREAD
- * only the QT event thread should do GUI operations,
+ * only the TQt event thread should do GUI operations,
* we use TQApplication::postEvent() and a reimplementation of TQObject::timerEvent() to
@@ -364,9 +364,9 @@ void KXineWidget::frameOutputCallback(void* p, int video_width, int video_height
* we use TQApplication::postEvent() and a reimplementation of TQObject::timerEvent() to
- * make sure all critical jobs are done within the QT main thread context
+ * make sure all critical jobs are done within the TQt main thread context
*
* for more information see http://doc.trolltech.com/3.1/threads.html